##  Changing Permissions for Reports and Diagrams
To add a report or diagram to a presentation, ensure that it's accessible to all workspace users. If a report or diagram is missing from the list, modify its permissions to either Can edit or Can view.
  * Report: To change report permissions, in the upper-right corner of the report page, click the three-dot icon > Report details. On the report details page, navigate to the Permissions tab, then update permissions to either Can edit or Can view. To learn more, see [Report Permissions](https://help.sap.com/docs/leanix/ea/using-reports?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a74687a441014a0988e439b9077b4__report_permissions).
  * Diagram: To change diagram permissions, in the upper-right corner of the diagram page, click the three-dot icon > Diagram details. On the diagram details page, navigate to the Permissions tab, then update permissions to either Can edit or Can view. To learn more, see [Permissions and Ownership of Diagrams](https://help.sap.com/docs/leanix/ea/diagrams?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759cc477a441014b234d2b2f9428243__Permissions-and-Ownership-of-Diagrams).


**Note**
A report or diagram whose permissions are changed to No access becomes unavailable in presentations.
